// Illustrates bug
// http://bugzilla.ecoinformatics.org/show_bug.cgi?id=3801
// where setting the stylesheet of an HTMLEditorKit changes
// the Windows native look and feel JFileChooser.
// What happens is that the text of the Windows Places Bar,
// which usually has icons and text for "My Recent Documents"
// "Desktop", "My Documents", "My Computer" etc. gets changed
// so that the text background is the same as the HTML body background
// which is set the same as the style sheet.

// Based on code from http://www.cusc.ctu.edu.vn/forum/index.php?PHPSESSID=0020d8bc5a9edaa9a320d7aae1f81df4&topic=167.msg458

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.net.URL;
import java.util.*;

import javax.swing.*;
import javax.swing.text.*;
import javax.swing.event.*;
import javax.swing.border.*;
import javax.swing.text.html.*;

public class HTMLCSSWindowsFileChooserBug extends JFrame {

   protected JTextPane editor;
   protected HTMLDocument doc;
   protected HTMLEditorKit kit;
   protected JFileChooser chooser;

   public HTMLCSSWindowsFileChooserBug() throws Exception {
      super("HTMLEditorKit/JFileChooser/Stylesheet bug");
      setSize(650, 400);

      editor = new JTextPane();
      kit = new HTMLEditorKit();
      editor.setEditorKit(kit);

      // Set the style sheet
      HTMLDocument doc = (HTMLDocument) editor.getDocument();
      StyleSheet styleSheet = doc.getStyleSheet();
            Class refClass = Class.forName("HTMLCSSWindowsFileChooserBug");
      URL _styleSheetURL = refClass.getClassLoader().getResource(
              "HTMLProcessor.css");
      styleSheet.importStyleSheet(_styleSheetURL);
      kit.setStyleSheet(styleSheet);

      JScrollPane ps = new JScrollPane(editor);
      getContentPane().add(ps, BorderLayout.CENTER);

      JMenuBar menuBar = createMenuBar();
      setJMenuBar(menuBar);

      chooser = new JFileChooser();

      doc = (HTMLDocument)kit.createDefaultDocument();

      editor.setDocument(doc);

      WindowListener wndCloser = new WindowAdapter() {
         public void windowClosing(WindowEvent e) {
            System.exit(0);
         }
      };
      addWindowListener(wndCloser);
   }

   protected JMenuBar createMenuBar() {
      JMenuBar menuBar = new JMenuBar();

      JMenu mFile = new JMenu("File");

      Action actionOpen = new AbstractAction("Open...") {
         public void actionPerformed(ActionEvent e) {
             chooser.showOpenDialog(HTMLCSSWindowsFileChooserBug.this);
         }
      };
      JMenuItem item = new JMenuItem(actionOpen);
      mFile.add(item);

      menuBar.add(mFile);
      return menuBar;
   }

   public static void main(String argv[]) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                try {
                    UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());

                    HTMLCSSWindowsFileChooserBug frame = new HTMLCSSWindowsFileChooserBug();
                    frame.setVisible(true);
                } catch (Exception e) {
                    e.printStackTrace();
                }
	    }
	    });
   }
}
